@@ -10,7 +10,7 @@ from . import _defaults
 from ._logger import Core as _Core
 from ._logger import Logger as _Logger
 
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 
 __all__ = ["logger"]
 
@@ -23,7 +23,7 @@ logger = _Logger(
     colors=False,
     raw=False,
     capture=True,
-    patcher=None,
+    patchers=[],
     extra={},
 )
 
